from datetime import datetime

import pytz
from reportlab.pdfgen.canvas import Canvas


class NumberedPageCanvas(Canvas):
    """
    http://code.activestate.com/recipes/546511-page-x-of-y-with-reportlab/
    http://code.activestate.com/recipes/576832/
    http://www.blog.pythonlibrary.org/2013/08/12/reportlab-how-to-add-page-numbers/
    """

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.pages = []
        self.bookmarks = {}

    def closePage(self):
        self.pages.append(dict(self.__dict__))

    def showPage(self):
        self.closePage()
        self._startPage()

    def save(self):
        page_count = len(self.pages)

        date = datetime.utcnow().astimezone(pytz.timezone("Europe/Paris")).strftime('%d/%m/%Y %H:%M')

        for page in self.pages:
            self.__dict__.update(page)
            self.draw_page_number(page_count, date)
            super().showPage()

        super().save()

    def presetBookmarkPage(self, key):
        if self._pageNumber in self.bookmarks:
            self.bookmarks[self._pageNumber].append(key)
        else:
            self.bookmarks[self._pageNumber] = [key]

    def draw_page_number(self, page_count, date):
        page = "Page %s sur %s" % (self._pageNumber, page_count)
        if self._pageNumber in self.bookmarks:
            for key in self.bookmarks[self._pageNumber]:
                self.bookmarkPage(key)
        self.setFont("Helvetica", 9)
        self.drawString(30, 30, date)
        self.drawRightString(self._pagesize[0]-80, 30, page)
        #self.drawRightString(179 * mm, -280 * mm, page)


from django.conf.urls import url

from foledol.django import auth
from foledol.django.views import logs, grids, grid, columns, column, conditions, condition

app_name = "django"

urlpatterns = [
    url(r'user_login/', auth.user_login, name='user_login'),
    url(r'user_logout/', auth.user_logout, name='user_logout'),

    url(r'logs', logs.log_list, name='logs'),
    url(r'log_plot_today', logs.log_plot_today, name='log_plot_today'),
    url(r'log_plot', logs.log_plot, name='log_plot'),
    url(r'log_events', logs.log_events, name='log_events'),
    url(r'log_update/(?P<pk>\d+)', logs.log_update, name='log_update'),

    url(r'grids', grids.grid_list, name='grids'),
    url(r'grid_create/', grid.grid_create, name='grid_create'),
    url(r'grid_update/(?P<pk>\d+)', grid.grid_update, name='grid_update'),
    url(r'grid_delete/(?P<pk>\d+)', grid.grid_delete, name='grid_delete'),
    url(r'grid_view/(?P<pk>\d+)', grid.grid_view, name='grid_view'),

    url(r'columns', columns.column_list, name='columns'),
    url(r'column_create/', column.column_create, name='column_create'),
    url(r'column_update/(?P<pk>\d+)', column.column_update, name='column_update'),
    url(r'column_delete/(?P<pk>\d+)', column.column_delete, name='column_delete'),

    url(r'conditions', conditions.condition_list, name='conditions'),
    url(r'condition_create/', condition.condition_create, name='condition_create'),
    url(r'condition_update/(?P<pk>\d+)', condition.condition_update, name='condition_update'),
    url(r'condition_delete/(?P<pk>\d+)', condition.condition_delete, name='condition_delete'),
]


